==> jc-1.4.0.tar.gz: java/net/PasswordAuthentication.h <==
// public final class java.net.PasswordAuthentication

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class dad0c2390a9d10f2 java_net_PasswordAuthentication

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_net_PasswordAuthentication_H_
#define _JC_java_net_PasswordAuthentication_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_PasswordAuthentication$sub_refs	_jc_java_net_PasswordAuthentication$sub_refs;
typedef struct _jc_java_net_PasswordAuthentication$sub_nonrefs	_jc_java_net_PasswordAuthentication$sub_nonrefs;
typedef struct _jc_java_net_PasswordAuthentication$refs	_jc_java_net_PasswordAuthentication$refs;
typedef struct _jc_java_net_PasswordAuthentication$nonrefs	_jc_java_net_PasswordAuthentication$nonrefs;
typedef struct _jc_java_net_PasswordAuthentication$object	_jc_java_net_PasswordAuthentication$object;

typedef const struct _jc_java_net_PasswordAuthentication$vmethods	_jc_java_net_PasswordAuthentication$vmethods;
typedef const struct _jc_java_net_PasswordAuthentication$vtable	_jc_java_net_PasswordAuthentication$vtable;
typedef const struct _jc_java_net_PasswordAuthentication$vtype	_jc_java_net_PasswordAuthentication$vtype;

// Constructors
extern void _jc_java_net_PasswordAuthentication$method$_init$c43892a3c8ac5541(_jc_env *, struct _jc_java_net_PasswordAuthentication$object *, struct _jc_java_lang_String$object *, struct _jc_char_array *);

// Virtual methods
extern _jc_char_array *_jc_java_net_PasswordAuthentication$method$getPassword$6adf0c63e283126f(_jc_env *, struct _jc_java_net_PasswordAuthentication$object *);
extern struct _jc_java_lang_String$object *_jc_java_net_PasswordAuthentication$method$getUserName$ccf38f85d7c727d5(_jc_env *, struct _jc_java_net_PasswordAuthentication$object *);

// Virtual method descriptors
extern _jc_method _jc_java_net_PasswordAuthentication$method_info$getPassword$6adf0c63e283126f;
extern _jc_method _jc_java_net_PasswordAuthentication$method_info$getUserName$ccf38f85d7c727d5;

// Virtual methods structure
struct _jc_java_net_PasswordAuthentication$vmethods {
	_jc_char_array	*(*getPassword$6adf0c63e283126f)(_jc_env *, struct _jc_java_net_PasswordAuthentication$object *);
	struct _jc_java_lang_String$object	*(*getUserName$ccf38f85d7c727d5)(_jc_env *, struct _jc_java_net_PasswordAuthentication$object *);
};

// Vtable
struct _jc_java_net_PasswordAuthentication$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_PasswordAuthentication$vmethods	java_net_PasswordAuthentication;
};

// Vtype
struct _jc_java_net_PasswordAuthentication$vtype {
	_jc_type			type;
	_jc_java_net_PasswordAuthentication$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_PasswordAuthentication$sub_refs {
	struct _jc_java_lang_String$object	*username;
	_jc_char_array	*password;
};

// Reference instance fields (object)
struct _jc_java_net_PasswordAuthentication$refs {
    _jc_java_net_PasswordAuthentication$sub_refs	java_net_PasswordAuthentication;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_PasswordAuthentication$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_PasswordAuthentication$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_PasswordAuthentication$sub_nonrefs	java_net_PasswordAuthentication;
};

// Object instance structure
struct _jc_java_net_PasswordAuthentication$object {
	_jc_java_net_PasswordAuthentication$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_PasswordAuthentication$vtype	*vtype;
	_jc_java_net_PasswordAuthentication$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_PasswordAuthentication$vtype _jc_java_net_PasswordAuthentication$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_PasswordAuthentication, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_PasswordAuthentication$class_object;

#endif	/* _JC_java_net_PasswordAuthentication_H_ */

==> jc-1.4.6.tar.gz: java/net/PasswordAuthentication.h <==
// public final class java.net.PasswordAuthentication

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class dad0c2390a9d10f2 java_net_PasswordAuthentication

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_net_PasswordAuthentication_H_
#define _JC_java_net_PasswordAuthentication_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_PasswordAuthentication$sub_refs	_jc_java_net_PasswordAuthentication$sub_refs;
typedef struct _jc_java_net_PasswordAuthentication$sub_nonrefs	_jc_java_net_PasswordAuthentication$sub_nonrefs;
typedef struct _jc_java_net_PasswordAuthentication$refs	_jc_java_net_PasswordAuthentication$refs;
typedef struct _jc_java_net_PasswordAuthentication$nonrefs	_jc_java_net_PasswordAuthentication$nonrefs;
typedef struct _jc_java_net_PasswordAuthentication$object	_jc_java_net_PasswordAuthentication$object;

typedef const struct _jc_java_net_PasswordAuthentication$vmethods	_jc_java_net_PasswordAuthentication$vmethods;
typedef const struct _jc_java_net_PasswordAuthentication$vtable	_jc_java_net_PasswordAuthentication$vtable;
typedef const struct _jc_java_net_PasswordAuthentication$vtype	_jc_java_net_PasswordAuthentication$vtype;

// Constructors
extern void _jc_java_net_PasswordAuthentication$method$_init$c43892a3c8ac5541(_jc_env *, struct _jc_java_net_PasswordAuthentication$object *, struct _jc_java_lang_String$object *, struct _jc_char_array *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_char_array *_jc_java_net_PasswordAuthentication$method$getPassword$6adf0c63e283126f(_jc_env *, struct _jc_java_net_PasswordAuthentication$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_net_PasswordAuthentication$method$getUserName$ccf38f85d7c727d5(_jc_env *, struct _jc_java_net_PasswordAuthentication$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_net_PasswordAuthentication$method_info$getPassword$6adf0c63e283126f;
extern _jc_method _jc_java_net_PasswordAuthentication$method_info$getUserName$ccf38f85d7c727d5;

// Virtual methods structure
struct _jc_java_net_PasswordAuthentication$vmethods {
	_jc_char_array	*(*getPassword$6adf0c63e283126f)(_jc_env *, struct _jc_java_net_PasswordAuthentication$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getUserName$ccf38f85d7c727d5)(_jc_env *, struct _jc_java_net_PasswordAuthentication$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_net_PasswordAuthentication$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_PasswordAuthentication$vmethods	java_net_PasswordAuthentication;
};

// Vtype
struct _jc_java_net_PasswordAuthentication$vtype {
	_jc_type			type;
	_jc_java_net_PasswordAuthentication$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_PasswordAuthentication$sub_refs {
	struct _jc_java_lang_String$object	*username;
	_jc_char_array	*password;
};

// Reference instance fields (object)
struct _jc_java_net_PasswordAuthentication$refs {
    _jc_java_net_PasswordAuthentication$sub_refs	java_net_PasswordAuthentication;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_PasswordAuthentication$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_PasswordAuthentication$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_PasswordAuthentication$sub_nonrefs	java_net_PasswordAuthentication;
};

// Object instance structure
struct _jc_java_net_PasswordAuthentication$object {
	_jc_java_net_PasswordAuthentication$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_PasswordAuthentication$vtype	*vtype;
	_jc_java_net_PasswordAuthentication$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_PasswordAuthentication$vtype _jc_java_net_PasswordAuthentication$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_PasswordAuthentication, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_PasswordAuthentication$class_object;

#endif	/* _JC_java_net_PasswordAuthentication_H_ */
